pub enum NodeGraphModifierKey {
None,
CtrlOrMeta,
Shift,
Alt,
}Expand description
Modifier requirement for interaction activation (XyFlow mental model).
This is used for zoom activation (zoomActivationKey), selection activation (selectionKeyCode),
and multi-selection (multiSelectionKeyCode).
Variants
None
Wheel zoom is always active (no activation modifier required).
CtrlOrMeta
Wheel zoom is active only while Ctrl or Meta is held (recommended default).
Shift
Wheel zoom is active only while Shift is held.
Alt
Wheel zoom is active only while Alt is held.
Implementations
Sourceimpl NodeGraphModifierKey
impl NodeGraphModifierKey
pub fn is_pressed(self, modifiers: NodeGraphModifiers) -> bool