pub struct NodeGraphConnectionInteraction<'a> {
pub nodes_connectable: bool,
pub edges_reconnectable: bool,
pub connection_mode: NodeGraphConnectionMode,
pub connection_radius: f32,
pub reconnect_radius: f32,
pub reconnect_on_drop_empty: bool,
pub connection_drag_threshold: f32,
pub connect_on_click: bool,
pub reroute_on_edge_double_click: bool,
pub edge_insert_on_alt_drag: bool,
pub edge_hit_test: EdgeHitTestOptions,
pub auto_pan: &'a NodeGraphAutoPanTuning,
}Expand description
Connection gesture and edge interaction settings resolved for runtime use.
Fields
nodes_connectable: booledges_reconnectable: boolconnection_mode: NodeGraphConnectionModeconnection_radius: f32reconnect_radius: f32reconnect_on_drop_empty: boolconnection_drag_threshold: f32connect_on_click: boolreroute_on_edge_double_click: booledge_insert_on_alt_drag: booledge_hit_test: EdgeHitTestOptionsauto_pan: &'a NodeGraphAutoPanTuningTrait Implementations
Sourceimpl<'a> Clone for NodeGraphConnectionInteraction<'a>
impl<'a> Clone for NodeGraphConnectionInteraction<'a>
Sourcefn clone(&self) -> NodeGraphConnectionInteraction<'a>
fn clone(&self) -> NodeGraphConnectionInteraction<'a>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl<'a> Copy for NodeGraphConnectionInteraction<'a>
Sourceimpl<'a> Debug for NodeGraphConnectionInteraction<'a>
impl<'a> Debug for NodeGraphConnectionInteraction<'a>
Sourceimpl<'a> PartialEq for NodeGraphConnectionInteraction<'a>
impl<'a> PartialEq for NodeGraphConnectionInteraction<'a>
Sourcefn eq(&self, other: &NodeGraphConnectionInteraction<'a>) -> bool
fn eq(&self, other: &NodeGraphConnectionInteraction<'a>) -> bool
Tests for
self and other values to be equal, and is used by ==.impl<'a> StructuralPartialEq for NodeGraphConnectionInteraction<'a>