pub struct NodeGraphDeleteInteraction {
pub nodes_deletable: bool,
pub edges_deletable: bool,
pub delete_key: NodeGraphDeleteKey,
}Expand description
Delete policy and keyboard binding resolved for runtime use.
Fields
nodes_deletable: booledges_deletable: booldelete_key: NodeGraphDeleteKeyTrait Implementations
Sourceimpl Clone for NodeGraphDeleteInteraction
impl Clone for NodeGraphDeleteInteraction
Sourcefn clone(&self) -> NodeGraphDeleteInteraction
fn clone(&self) -> NodeGraphDeleteInteraction
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for NodeGraphDeleteInteraction
Sourceimpl Debug for NodeGraphDeleteInteraction
impl Debug for NodeGraphDeleteInteraction
impl Eq for NodeGraphDeleteInteraction
Sourceimpl PartialEq for NodeGraphDeleteInteraction
impl PartialEq for NodeGraphDeleteInteraction
Sourcefn eq(&self, other: &NodeGraphDeleteInteraction) -> bool
fn eq(&self, other: &NodeGraphDeleteInteraction) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for NodeGraphDeleteInteraction