pub struct NodeGraphKeyboardInteraction {
pub nodes_focusable: bool,
pub edges_focusable: bool,
pub delete_key: NodeGraphDeleteKey,
pub nudge_step_mode: NodeGraphNudgeStepMode,
pub nudge_step_px: f32,
pub nudge_fast_step_px: f32,
pub disable_keyboard_a11y: bool,
}Expand description
Keyboard accessibility and nudge settings resolved for runtime use.
Fields
nodes_focusable: booledges_focusable: booldelete_key: NodeGraphDeleteKeynudge_step_mode: NodeGraphNudgeStepModenudge_step_px: f32nudge_fast_step_px: f32disable_keyboard_a11y: boolTrait Implementations
Sourceimpl Clone for NodeGraphKeyboardInteraction
impl Clone for NodeGraphKeyboardInteraction
Sourcefn clone(&self) -> NodeGraphKeyboardInteraction
fn clone(&self) -> NodeGraphKeyboardInteraction
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for NodeGraphKeyboardInteraction
Sourceimpl Debug for NodeGraphKeyboardInteraction
impl Debug for NodeGraphKeyboardInteraction
Sourceimpl PartialEq for NodeGraphKeyboardInteraction
impl PartialEq for NodeGraphKeyboardInteraction
Sourcefn eq(&self, other: &NodeGraphKeyboardInteraction) -> bool
fn eq(&self, other: &NodeGraphKeyboardInteraction) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for NodeGraphKeyboardInteraction