pub struct NodeGraphPanOnDragButtons {
pub left: bool,
pub middle: bool,
pub right: bool,
}Fields
left: boolPan the canvas by dragging on empty background with the left mouse button.
middle: boolPan the canvas by dragging with the middle mouse button.
right: boolPan the canvas by dragging with the right mouse button.
When enabled, apps should provide an alternate way to open context menus (or make context
menus conditional on “click without pan”), matching XyFlow’s panOnDrag={[2]} patterns.