pub struct NodeGraphPureViewState {
pub pan: CanvasPoint,
pub zoom: f32,
pub selected_nodes: Vec<NodeId>,
pub selected_edges: Vec<EdgeId>,
pub selected_groups: Vec<GroupId>,
pub draw_order: Vec<NodeId>,
pub edge_draw_order: Vec<EdgeId>,
pub group_draw_order: Vec<GroupId>,
}Expand description
Pure persisted view-state payload.
This excludes interaction policy and runtime tuning so persistence boundaries can evolve without forcing every in-memory/runtime consumer to change in the same step.
Fields
pan: CanvasPointzoom: f32selected_nodes: Vec<NodeId>selected_edges: Vec<EdgeId>selected_groups: Vec<GroupId>draw_order: Vec<NodeId>edge_draw_order: Vec<EdgeId>group_draw_order: Vec<GroupId>Trait Implementations
Sourceimpl Clone for NodeGraphPureViewState
impl Clone for NodeGraphPureViewState
Sourcefn clone(&self) -> NodeGraphPureViewState
fn clone(&self) -> NodeGraphPureViewState
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NodeGraphPureViewState
impl Debug for NodeGraphPureViewState
Sourceimpl Default for NodeGraphPureViewState
impl Default for NodeGraphPureViewState
Sourceimpl<'de> Deserialize<'de> for NodeGraphPureViewState
impl<'de> Deserialize<'de> for NodeGraphPureViewState
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&NodeGraphViewState> for NodeGraphPureViewState
impl From<&NodeGraphViewState> for NodeGraphPureViewState
Sourcefn from(value: &NodeGraphViewState) -> Self
fn from(value: &NodeGraphViewState) -> Self
Converts to this type from the input type.
Sourceimpl From<NodeGraphPureViewState> for NodeGraphViewState
impl From<NodeGraphPureViewState> for NodeGraphViewState
Sourcefn from(value: NodeGraphPureViewState) -> Self
fn from(value: NodeGraphPureViewState) -> Self
Converts to this type from the input type.
Sourceimpl From<NodeGraphViewState> for NodeGraphPureViewState
impl From<NodeGraphViewState> for NodeGraphPureViewState
Sourcefn from(value: NodeGraphViewState) -> Self
fn from(value: NodeGraphViewState) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for NodeGraphPureViewState
impl PartialEq for NodeGraphPureViewState
Sourcefn eq(&self, other: &NodeGraphPureViewState) -> bool
fn eq(&self, other: &NodeGraphPureViewState) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for NodeGraphPureViewState
impl Serialize for NodeGraphPureViewState
impl StructuralPartialEq for NodeGraphPureViewState