pub fn plan_delete_elements(
graph: &Graph,
nodes: impl IntoIterator<Item = NodeId>,
edges: impl IntoIterator<Item = EdgeId>,
) -> DeletePlanExpand description
Plans deleting nodes and edges with default interaction policy.
pub fn plan_delete_elements(
graph: &Graph,
nodes: impl IntoIterator<Item = NodeId>,
edges: impl IntoIterator<Item = EdgeId>,
) -> DeletePlanPlans deleting nodes and edges with default interaction policy.