pub struct InsertNodeTemplate {
pub kind: NodeKindKey,
pub kind_version: u32,
pub collapsed: bool,
pub data: Value,
pub ports: Vec<PortTemplate>,
pub input: PortKey,
pub output: PortKey,
}Expand description
A template for inserting a node between two ports.
This is the preferred UI-to-rules contract: IDs are generated by the rules layer.
Fields
kind: NodeKindKeykind_version: u32collapsed: booldata: Valueports: Vec<PortTemplate>input: PortKeyWhich instantiated port should be connected from the upstream edge segment.
output: PortKeyWhich instantiated port should be connected to the downstream edge segment.
Implementations
Sourceimpl InsertNodeTemplate
impl InsertNodeTemplate
Sourcepub fn instantiate(&self, at: CanvasPoint) -> Result<InsertNodeSpec, String>
pub fn instantiate(&self, at: CanvasPoint) -> Result<InsertNodeSpec, String>
Instantiates this template at a given position by allocating fresh IDs.