pub enum ConnectionHandleValidity {
Valid,
Invalid,
NoHandle,
}Expand description
XyFlow-compatible validity state for a connection target candidate.
Variants
Valid
A candidate handle is present and can accept the connection.
Invalid
A candidate handle is present or inside the connection radius, but cannot accept it.
NoHandle
No handle is close enough to report valid or invalid feedback.