pub struct ConnectionDragActivationInput {
pub screen_delta: CanvasPoint,
pub threshold: f32,
}Expand description
Screen-space input for deciding whether a connection drag should activate.
XyFlow evaluates connectionDragThreshold in client/screen coordinates, using squared
distance, so zoom does not change when connection gestures start.
Fields
screen_delta: CanvasPointthreshold: f32Implementations
Sourceimpl ConnectionDragActivationInput
impl ConnectionDragActivationInput
pub fn new(screen_delta: CanvasPoint, threshold: f32) -> Self