pub fn delete_elements_from_plan(plan: &DeletePlan) -> DeleteElementsExpand description
Extracts the actual node/edge ids removed by a delete plan, including cascaded edges.
pub fn delete_elements_from_plan(plan: &DeletePlan) -> DeleteElementsExtracts the actual node/edge ids removed by a delete plan, including cascaded edges.