pub struct NodeDragRequest {
pub node: NodeId,
pub to: CanvasPoint,
}Expand description
Canvas-space request for moving a primary node to a target position.
When used through crate::runtime::store::NodeGraphStore, currently selected nodes are
co-dragged with the primary node when policy allows them to move.
Fields
node: NodeIdPrimary node being moved.
to: CanvasPointTarget primary-node position in canvas space.