Module geometry

Module geometry 

Renderer-neutral geometry primitives for Jellyflow runtimes and adapters.

Structs

BezierEdgeOptions
Bezier edge options.
EdgeEndpointInput
Input for resolving one edge endpoint.
EdgeEndpointPosition
Resolved edge endpoint in canvas space.
EdgeHitTestOptions
Options for numeric edge hit testing.
EdgePath
Renderer-neutral edge path.
EdgePathLabel
Label placement derived from an edge path.
EdgePosition
Resolved source and target endpoint geometry in canvas space.
HandleBounds
Renderer-neutral handle bounds relative to the owning node’s top-left corner.
SmoothStepEdgeOptions
Smoothstep-like edge options.

Enums

HandlePosition
Side of a node or handle where an edge endpoint attaches.
PathCommand
Renderer-neutral path command.

Functions

bezier_edge_path
edge_path_contains_point
edge_path_distance
edge_position
handle_anchor_position
handle_center_position
smoothstep_edge_path
straight_edge_path