pub struct EdgePosition {
pub source: EdgeEndpointPosition,
pub target: EdgeEndpointPosition,
}Expand description
Resolved source and target endpoint geometry in canvas space.
Fields
source: EdgeEndpointPositiontarget: EdgeEndpointPositionTrait Implementations
Sourceimpl Clone for EdgePosition
impl Clone for EdgePosition
Sourcefn clone(&self) -> EdgePosition
fn clone(&self) -> EdgePosition
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for EdgePosition
Sourceimpl Debug for EdgePosition
impl Debug for EdgePosition
Sourceimpl PartialEq for EdgePosition
impl PartialEq for EdgePosition
Sourcefn eq(&self, other: &EdgePosition) -> bool
fn eq(&self, other: &EdgePosition) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for EdgePosition