pub enum KeyboardIntent {
DeleteSelection,
DeleteSelectionForKey(Code),
NudgeSelection(NodeNudgeRequest),
}Expand description
High-level keyboard intent handled by the headless runtime.
Variants
DeleteSelection
Delete the current selection without checking a key binding.
DeleteSelectionForKey(Code)
Delete the current selection if the provided key matches the configured binding.
NudgeSelection(NodeNudgeRequest)
Nudge the current selected nodes.