LayoutScope

Enum LayoutScope 

pub enum LayoutScope {
    All,
    Nodes {
        nodes: BTreeSet<NodeId>,
    },
}
Which nodes a layout request should include.

Variants



All

Include all non-hidden nodes.



Nodes

Include only these nodes. Hidden nodes are still ignored.

Fields

Implementations

Source

impl LayoutScope

pub fn from_footprint( graph: &Graph, footprint: &GraphMutationFootprint, ) -> LayoutScope

Derives a conservative node scope from a graph mutation footprint and the current graph.

Direct node changes are included. Port and edge changes expand to their owning endpoint nodes when that information is available in the current graph snapshot. Node ids that no longer exist in the supplied graph are omitted.

pub fn from_transaction(graph: &Graph, tx: &GraphTransaction) -> LayoutScope

Derives a conservative node scope from a transaction and the current graph.

pub fn is_empty(&self) -> bool

Returns true when this scope selects no nodes.

pub fn nodes(&self) -> Option<&BTreeSet<NodeId>>

Returns selected nodes when this is a node-limited scope.