pub struct LayoutContext {
pub measured_node_sizes: BTreeMap<NodeId, CanvasSize>,
pub pinned_nodes: BTreeSet<NodeId>,
pub node_origin: Option<(f32, f32)>,
}Expand description
Runtime or host-owned context available to layout engines.
Fields
measured_node_sizes: BTreeMap<NodeId, CanvasSize>Runtime-reported node sizes. Graph node sizes and request-local measured sizes win.
pinned_nodes: BTreeSet<NodeId>Nodes that engines should treat as fixed when they support pinning.
node_origin: Option<(f32, f32)>Runtime fallback node origin, usually resolved from interaction state.
Implementations
Sourceimpl LayoutContext
impl LayoutContext
Sourcepub fn new() -> LayoutContext
pub fn new() -> LayoutContext
Creates an empty layout context.
Sourcepub fn with_measured_node_sizes(
self,
sizes: impl IntoIterator<Item = (NodeId, CanvasSize)>,
) -> LayoutContext
pub fn with_measured_node_sizes( self, sizes: impl IntoIterator<Item = (NodeId, CanvasSize)>, ) -> LayoutContext
Adds runtime-reported node sizes.
Sourcepub fn with_pinned_nodes(
self,
nodes: impl IntoIterator<Item = NodeId>,
) -> LayoutContext
pub fn with_pinned_nodes( self, nodes: impl IntoIterator<Item = NodeId>, ) -> LayoutContext
Adds nodes that engines should keep fixed when possible.
Sourcepub fn with_node_origin(self, node_origin: (f32, f32)) -> LayoutContext
pub fn with_node_origin(self, node_origin: (f32, f32)) -> LayoutContext
Sets the runtime fallback node origin.