pub struct LayoutOptions {
pub direction: LayoutDirection,
pub spacing: LayoutSpacing,
pub margin: CanvasSize,
pub default_node_size: CanvasSize,
pub node_origin: (f32, f32),
}Expand description
Options shared by Jellyflow layout adapters.
Fields
direction: LayoutDirectionspacing: LayoutSpacingmargin: CanvasSizedefault_node_size: CanvasSizenode_origin: (f32, f32)Fallback node origin used when a node has no per-node origin override.
Implementations
Sourceimpl LayoutOptions
impl LayoutOptions
Sourcepub fn with_default_node_size(self, size: CanvasSize) -> LayoutOptions
pub fn with_default_node_size(self, size: CanvasSize) -> LayoutOptions
Uses a different fallback node size for nodes without explicit or measured size.
Sourcepub fn with_direction(self, direction: LayoutDirection) -> LayoutOptions
pub fn with_direction(self, direction: LayoutDirection) -> LayoutOptions
Uses a different layered layout direction.
Sourcepub fn with_node_origin(self, node_origin: (f32, f32)) -> LayoutOptions
pub fn with_node_origin(self, node_origin: (f32, f32)) -> LayoutOptions
Uses a different fallback node origin.