pub struct LayoutResult {
pub nodes: Vec<LayoutNodePosition>,
pub edge_routes: Vec<LayoutEdgeRoute>,
pub bounds: Option<CanvasRect>,
}Expand description
Result of a headless layout run.
Fields
nodes: Vec<LayoutNodePosition>Engine-produced results contain at most one entry per node. If a caller manually constructs a result with duplicates, lookup returns the first entry and transaction conversion fails.
edge_routes: Vec<LayoutEdgeRoute>bounds: Option<CanvasRect>Implementations
Sourceimpl LayoutResult
impl LayoutResult
Sourcepub fn node_position(&self, node: NodeId) -> Option<LayoutNodePosition>
pub fn node_position(&self, node: NodeId) -> Option<LayoutNodePosition>
Finds one node position in this result.
Sourcepub fn to_transaction(
&self,
graph: &Graph,
) -> Result<GraphTransaction, LayoutError>
pub fn to_transaction( &self, graph: &Graph, ) -> Result<GraphTransaction, LayoutError>
Converts node position changes into a Jellyflow transaction.