pub struct LayoutSpacing {
pub nodesep: f32,
pub ranksep: f32,
pub edgesep: f32,
}Expand description
Spacing knobs passed through to layout engines that support layered spacing.
Fields
nodesep: f32ranksep: f32edgesep: f32Trait Implementations
Sourceimpl Clone for LayoutSpacing
impl Clone for LayoutSpacing
Sourcefn clone(&self) -> LayoutSpacing
fn clone(&self) -> LayoutSpacing
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for LayoutSpacing
Sourceimpl Debug for LayoutSpacing
impl Debug for LayoutSpacing
Sourceimpl Default for LayoutSpacing
impl Default for LayoutSpacing
Sourcefn default() -> LayoutSpacing
fn default() -> LayoutSpacing
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for LayoutSpacing
impl<'de> Deserialize<'de> for LayoutSpacing
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<LayoutSpacing, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<LayoutSpacing, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for LayoutSpacing
impl PartialEq for LayoutSpacing
Sourcefn eq(&self, other: &LayoutSpacing) -> bool
fn eq(&self, other: &LayoutSpacing) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for LayoutSpacing
impl Serialize for LayoutSpacing
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for LayoutSpacing