pub fn plan_node_resize(
graph: &Graph,
request: NodeResizeRequest,
) -> Option<NodeResizePlan>Expand description
Plans a node resize update without mutating the graph.
pub fn plan_node_resize(
graph: &Graph,
request: NodeResizeRequest,
) -> Option<NodeResizePlan>Plans a node resize update without mutating the graph.