pub enum NodeDragStartSelectionAction {
Unchanged,
Clear,
SelectOnly(NodeId),
Add(NodeId),
Remove(NodeId),
}Expand description
Selection mutation implied by starting a node drag.
Variants
Unchanged
Keep the current selection unchanged.
Clear
Clear node, edge, and group selection.
SelectOnly(NodeId)
Select only the dragged node and clear edge/group selection.
Add(NodeId)
Add the dragged node to the existing node selection.
Remove(NodeId)
Remove the dragged node from the existing node selection.
Implementations
Sourceimpl NodeDragStartSelectionAction
impl NodeDragStartSelectionAction
pub fn is_unchanged(self) -> bool
pub fn apply_to_view_state(self, view_state: &mut NodeGraphViewState)