pub struct SelectionBoxOptions {
pub modifier: SelectionModifier,
pub fallback_size: Option<CanvasSize>,
}Expand description
Options for applying a marquee selection box.
Fields
modifier: SelectionModifierWhether the box result replaces or unions with the current selection.
fallback_size: Option<CanvasSize>Fallback size for nodes that do not have an explicit measured size.