pub fn get_connected_edges(
lookups: &NodeGraphLookups,
node: NodeId,
) -> Vec<EdgeId>Expand description
Returns all edges incident to the given node (both directions).
pub fn get_connected_edges(
lookups: &NodeGraphLookups,
node: NodeId,
) -> Vec<EdgeId>Returns all edges incident to the given node (both directions).