pub fn get_outgoers(lookups: &NodeGraphLookups, node: NodeId) -> Vec<NodeId>Expand description
Returns the nodes connected as targets of the given node’s outgoing edges.
pub fn get_outgoers(lookups: &NodeGraphLookups, node: NodeId) -> Vec<NodeId>Returns the nodes connected as targets of the given node’s outgoing edges.