pub struct NodeRepeatableItemProjection {
pub collection_key: String,
pub item_id: String,
pub item_index: usize,
pub slot_key: String,
pub anchor: String,
pub port_key: Option<String>,
pub item_data: Value,
pub slots: Vec<NodeSurfaceSlotDescriptor>,
}Expand description
Projected instance of one repeatable item for adapter rendering and measurement.
Fields
collection_key: Stringitem_id: Stringitem_index: usizeslot_key: Stringanchor: Stringport_key: Option<String>item_data: Valueslots: Vec<NodeSurfaceSlotDescriptor>Trait Implementations
Sourceimpl Clone for NodeRepeatableItemProjection
impl Clone for NodeRepeatableItemProjection
Sourcefn clone(&self) -> NodeRepeatableItemProjection
fn clone(&self) -> NodeRepeatableItemProjection
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NodeRepeatableItemProjection
impl Debug for NodeRepeatableItemProjection
Sourceimpl<'de> Deserialize<'de> for NodeRepeatableItemProjection
impl<'de> Deserialize<'de> for NodeRepeatableItemProjection
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for NodeRepeatableItemProjection
impl PartialEq for NodeRepeatableItemProjection
Sourcefn eq(&self, other: &NodeRepeatableItemProjection) -> bool
fn eq(&self, other: &NodeRepeatableItemProjection) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for NodeRepeatableItemProjection