pub struct NodeGraphPatch {
pub transaction: GraphTransaction,
}Expand description
Full-fidelity committed graph patch.
This is the primary commit payload for controlled integrations. It preserves every
GraphOp, including ports, groups, sticky notes, imports, symbols, and other resources.
Fields
transaction: GraphTransactionReversible transaction committed by the store.
Implementations
Sourceimpl NodeGraphPatch
impl NodeGraphPatch
pub fn new(transaction: GraphTransaction) -> Self
pub fn transaction(&self) -> &GraphTransaction
pub fn into_transaction(self) -> GraphTransaction
pub fn ops(&self) -> &[GraphOp]
pub fn is_empty(&self) -> bool